@@ -157,6 +157,7 @@ class UserCrud(CrudView):
                 fs.password.label("Set Password"),
                 fs.confirm_password,
                 fs.roles,
+                fs.active,
                 ])
 
         if self.readonly:
@@ -166,28 +167,31 @@ class UserCrud(CrudView):
         return fs
 
 
-def includeme(config):
+def add_routes(config):
+    config.add_route(u'users',          u'/users')
+    config.add_route(u'user.create',    u'/users/new')
+    config.add_route(u'user.read',      u'/users/{uuid}')
+    config.add_route(u'user.update',    u'/users/{uuid}/edit')
+    config.add_route(u'user.delete',    u'/users/{uuid}/delete')
 
-    config.add_route('users', '/users')
+
+def includeme(config):
+    add_routes(config)
+
+    # List
     config.add_view(UsersGrid, route_name='users',
                     renderer='/users/index.mako',
                     permission='users.list')
 
-    config.add_route('user.create', '/users/new')
+    # CRUD
     config.add_view(UserCrud, attr='create', route_name='user.create',
                     renderer='/users/crud.mako',
                     permission='users.create')
-
-    config.add_route('user.read', '/users/{uuid}')
     config.add_view(UserCrud, attr='read', route_name='user.read',
                     renderer='/users/crud.mako',
                     permission='users.read')
-
-    config.add_route('user.update', '/users/{uuid}/edit')
     config.add_view(UserCrud, attr='update', route_name='user.update',
                     renderer='/users/crud.mako',
                     permission='users.update')
-
-    config.add_route('user.delete', '/users/{uuid}/delete')
     config.add_view(UserCrud, attr='delete', route_name='user.delete',
                     permission='users.delete')
